package zdb

import (
	"time"
)

type Stat struct {
	Id   string
	Mode connMode
	Host string
	Port uint16

	AcquireCount            int64
	AcquireDuration         time.Duration
	AcquiredConns           int32
	CanceledAcquireCount    int64
	ConstructingConns       int32
	EmptyAcquireCount       int64
	IdleConns               int32
	MaxConns                int32
	TotalConns              int32
	NewConnsCount           int64
	MaxLifetimeDestroyCount int64
	MaxIdleDestroyCount     int64
}

func (d *Pool) StatMaster() *Stat {
	return d.stat(d.srvMaster)
}

func (d *Pool) stat(q *conn) *Stat {
	return &Stat{
		Id:                      q.ToString(),
		Mode:                    q.Mode,
		Host:                    q.Config().ConnConfig.Host,
		Port:                    q.Config().ConnConfig.Port,
		AcquireCount:            q.Stat().AcquireCount(),
		AcquireDuration:         q.Stat().AcquireDuration(),
		AcquiredConns:           q.Stat().AcquiredConns(),
		CanceledAcquireCount:    q.Stat().CanceledAcquireCount(),
		ConstructingConns:       q.Stat().ConstructingConns(),
		EmptyAcquireCount:       q.Stat().EmptyAcquireCount(),
		IdleConns:               q.Stat().IdleConns(),
		MaxConns:                q.Stat().MaxConns(),
		TotalConns:              q.Stat().TotalConns(),
		NewConnsCount:           q.Stat().NewConnsCount(),
		MaxLifetimeDestroyCount: q.Stat().MaxLifetimeDestroyCount(),
		MaxIdleDestroyCount:     q.Stat().MaxIdleDestroyCount(),
	}
}
